# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.email_audit_controller_api import EmailAuditControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestEmailAuditControllerApi(unittest.TestCase):
    """EmailAuditControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.email_audit_controller_api.EmailAuditControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_compare_email_audits(self):
        """Test case for compare_email_audits

        Compare two email audits  # noqa: E501
        """
        pass

    def test_create_email_audit(self):
        """Test case for create_email_audit

        Create email audit  # noqa: E501
        """
        pass

    def test_delete_email_audit(self):
        """Test case for delete_email_audit

        Delete email audit  # noqa: E501
        """
        pass

    def test_get_email_audit(self):
        """Test case for get_email_audit

        Get email audit  # noqa: E501
        """
        pass

    def test_get_email_audits(self):
        """Test case for get_email_audits

        List email audits  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class DevicePreviewProviderProgressDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'run': 'DevicePreviewRunDto',
        'provider': 'str',
        'status': 'str',
        'target_count': 'int',
        'ready_count': 'int',
        'failed_count': 'int',
        'capturing_count': 'int',
        'pending_count': 'int',
        'targets': 'list[DevicePreviewTargetDto]',
        'screenshots': 'list[DevicePreviewScreenshotDto]'
    }

    attribute_map = {
        'run': 'run',
        'provider': 'provider',
        'status': 'status',
        'target_count': 'targetCount',
        'ready_count': 'readyCount',
        'failed_count': 'failedCount',
        'capturing_count': 'capturingCount',
        'pending_count': 'pendingCount',
        'targets': 'targets',
        'screenshots': 'screenshots'
    }

    def __init__(self, run=None, provider=None, status=None, target_count=None, ready_count=None, failed_count=None, capturing_count=None, pending_count=None, targets=None, screenshots=None, local_vars_configuration=None):  # noqa: E501
        """DevicePreviewProviderProgressDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._run = None
        self._provider = None
        self._status = None
        self._target_count = None
        self._ready_count = None
        self._failed_count = None
        self._capturing_count = None
        self._pending_count = None
        self._targets = None
        self._screenshots = None
        self.discriminator = None

        self.run = run
        self.provider = provider
        self.status = status
        self.target_count = target_count
        self.ready_count = ready_count
        self.failed_count = failed_count
        self.capturing_count = capturing_count
        self.pending_count = pending_count
        self.targets = targets
        self.screenshots = screenshots

    @property
    def run(self):
        """Gets the run of this DevicePreviewProviderProgressDto.  # noqa: E501


        :return: The run of this DevicePreviewProviderProgressDto.  # noqa: E501
        :rtype: DevicePreviewRunDto
        """
        return self._run

    @run.setter
    def run(self, run):
        """Sets the run of this DevicePreviewProviderProgressDto.


        :param run: The run of this DevicePreviewProviderProgressDto.  # noqa: E501
        :type: DevicePreviewRunDto
        """
        if self.local_vars_configuration.client_side_validation and run is None:  # noqa: E501
            raise ValueError("Invalid value for `run`, must not be `None`")  # noqa: E501

        self._run = run

    @property
    def provider(self):
        """Gets the provider of this DevicePreviewProviderProgressDto.  # noqa: E501


        :return: The provider of this DevicePreviewProviderProgressDto.  # noqa: E501
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """Sets the provider of this DevicePreviewProviderProgressDto.


        :param provider: The provider of this DevicePreviewProviderProgressDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and provider is None:  # noqa: E501
            raise ValueError("Invalid value for `provider`, must not be `None`")  # noqa: E501
        allowed_values = ["GMAIL", "OUTLOOK", "YAHOO"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and provider not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `provider` ({0}), must be one of {1}"  # noqa: E501
                .format(provider, allowed_values)
            )

        self._provider = provider

    @property
    def status(self):
        """Gets the status of this DevicePreviewProviderProgressDto.  # noqa: E501


        :return: The status of this DevicePreviewProviderProgressDto.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this DevicePreviewProviderProgressDto.


        :param status: The status of this DevicePreviewProviderProgressDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and status is None:  # noqa: E501
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501
        allowed_values = ["PENDING", "CAPTURING", "PARTIAL_COMPLETE", "COMPLETE", "FAILED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def target_count(self):
        """Gets the target_count of this DevicePreviewProviderProgressDto.  # noqa: E501


        :return: The target_count of this DevicePreviewProviderProgressDto.  # noqa: E501
        :rtype: int
        """
        return self._target_count

    @target_count.setter
    def target_count(self, target_count):
        """Sets the target_count of this DevicePreviewProviderProgressDto.


        :param target_count: The target_count of this DevicePreviewProviderProgressDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and target_count is None:  # noqa: E501
            raise ValueError("Invalid value for `target_count`, must not be `None`")  # noqa: E501

        self._target_count = target_count

    @property
    def ready_count(self):
        """Gets the ready_count of this DevicePreviewProviderProgressDto.  # noqa: E501


        :return: The ready_count of this DevicePreviewProviderProgressDto.  # noqa: E501
        :rtype: int
        """
        return self._ready_count

    @ready_count.setter
    def ready_count(self, ready_count):
        """Sets the ready_count of this DevicePreviewProviderProgressDto.


        :param ready_count: The ready_count of this DevicePreviewProviderProgressDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and ready_count is None:  # noqa: E501
            raise ValueError("Invalid value for `ready_count`, must not be `None`")  # noqa: E501

        self._ready_count = ready_count

    @property
    def failed_count(self):
        """Gets the failed_count of this DevicePreviewProviderProgressDto.  # noqa: E501


        :return: The failed_count of this DevicePreviewProviderProgressDto.  # noqa: E501
        :rtype: int
        """
        return self._failed_count

    @failed_count.setter
    def failed_count(self, failed_count):
        """Sets the failed_count of this DevicePreviewProviderProgressDto.


        :param failed_count: The failed_count of this DevicePreviewProviderProgressDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and failed_count is None:  # noqa: E501
            raise ValueError("Invalid value for `failed_count`, must not be `None`")  # noqa: E501

        self._failed_count = failed_count

    @property
    def capturing_count(self):
        """Gets the capturing_count of this DevicePreviewProviderProgressDto.  # noqa: E501


        :return: The capturing_count of this DevicePreviewProviderProgressDto.  # noqa: E501
        :rtype: int
        """
        return self._capturing_count

    @capturing_count.setter
    def capturing_count(self, capturing_count):
        """Sets the capturing_count of this DevicePreviewProviderProgressDto.


        :param capturing_count: The capturing_count of this DevicePreviewProviderProgressDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and capturing_count is None:  # noqa: E501
            raise ValueError("Invalid value for `capturing_count`, must not be `None`")  # noqa: E501

        self._capturing_count = capturing_count

    @property
    def pending_count(self):
        """Gets the pending_count of this DevicePreviewProviderProgressDto.  # noqa: E501


        :return: The pending_count of this DevicePreviewProviderProgressDto.  # noqa: E501
        :rtype: int
        """
        return self._pending_count

    @pending_count.setter
    def pending_count(self, pending_count):
        """Sets the pending_count of this DevicePreviewProviderProgressDto.


        :param pending_count: The pending_count of this DevicePreviewProviderProgressDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and pending_count is None:  # noqa: E501
            raise ValueError("Invalid value for `pending_count`, must not be `None`")  # noqa: E501

        self._pending_count = pending_count

    @property
    def targets(self):
        """Gets the targets of this DevicePreviewProviderProgressDto.  # noqa: E501


        :return: The targets of this DevicePreviewProviderProgressDto.  # noqa: E501
        :rtype: list[DevicePreviewTargetDto]
        """
        return self._targets

    @targets.setter
    def targets(self, targets):
        """Sets the targets of this DevicePreviewProviderProgressDto.


        :param targets: The targets of this DevicePreviewProviderProgressDto.  # noqa: E501
        :type: list[DevicePreviewTargetDto]
        """
        if self.local_vars_configuration.client_side_validation and targets is None:  # noqa: E501
            raise ValueError("Invalid value for `targets`, must not be `None`")  # noqa: E501

        self._targets = targets

    @property
    def screenshots(self):
        """Gets the screenshots of this DevicePreviewProviderProgressDto.  # noqa: E501


        :return: The screenshots of this DevicePreviewProviderProgressDto.  # noqa: E501
        :rtype: list[DevicePreviewScreenshotDto]
        """
        return self._screenshots

    @screenshots.setter
    def screenshots(self, screenshots):
        """Sets the screenshots of this DevicePreviewProviderProgressDto.


        :param screenshots: The screenshots of this DevicePreviewProviderProgressDto.  # noqa: E501
        :type: list[DevicePreviewScreenshotDto]
        """
        if self.local_vars_configuration.client_side_validation and screenshots is None:  # noqa: E501
            raise ValueError("Invalid value for `screenshots`, must not be `None`")  # noqa: E501

        self._screenshots = screenshots

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DevicePreviewProviderProgressDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DevicePreviewProviderProgressDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class AccountBounceBlockDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'is_frozen': 'bool',
        'is_sending_blocked': 'bool',
        'bounce_count': 'int',
        'bounce_count_today': 'int',
        'maximum_daily_bounces': 'int',
        'maximum_account_bounces': 'int'
    }

    attribute_map = {
        'is_frozen': 'isFrozen',
        'is_sending_blocked': 'isSendingBlocked',
        'bounce_count': 'bounceCount',
        'bounce_count_today': 'bounceCountToday',
        'maximum_daily_bounces': 'maximumDailyBounces',
        'maximum_account_bounces': 'maximumAccountBounces'
    }

    def __init__(self, is_frozen=None, is_sending_blocked=None, bounce_count=None, bounce_count_today=None, maximum_daily_bounces=None, maximum_account_bounces=None, local_vars_configuration=None):  # noqa: E501
        """AccountBounceBlockDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._is_frozen = None
        self._is_sending_blocked = None
        self._bounce_count = None
        self._bounce_count_today = None
        self._maximum_daily_bounces = None
        self._maximum_account_bounces = None
        self.discriminator = None

        self.is_frozen = is_frozen
        self.is_sending_blocked = is_sending_blocked
        self.bounce_count = bounce_count
        self.bounce_count_today = bounce_count_today
        self.maximum_daily_bounces = maximum_daily_bounces
        self.maximum_account_bounces = maximum_account_bounces

    @property
    def is_frozen(self):
        """Gets the is_frozen of this AccountBounceBlockDto.  # noqa: E501


        :return: The is_frozen of this AccountBounceBlockDto.  # noqa: E501
        :rtype: bool
        """
        return self._is_frozen

    @is_frozen.setter
    def is_frozen(self, is_frozen):
        """Sets the is_frozen of this AccountBounceBlockDto.


        :param is_frozen: The is_frozen of this AccountBounceBlockDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and is_frozen is None:  # noqa: E501
            raise ValueError("Invalid value for `is_frozen`, must not be `None`")  # noqa: E501

        self._is_frozen = is_frozen

    @property
    def is_sending_blocked(self):
        """Gets the is_sending_blocked of this AccountBounceBlockDto.  # noqa: E501


        :return: The is_sending_blocked of this AccountBounceBlockDto.  # noqa: E501
        :rtype: bool
        """
        return self._is_sending_blocked

    @is_sending_blocked.setter
    def is_sending_blocked(self, is_sending_blocked):
        """Sets the is_sending_blocked of this AccountBounceBlockDto.


        :param is_sending_blocked: The is_sending_blocked of this AccountBounceBlockDto.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and is_sending_blocked is None:  # noqa: E501
            raise ValueError("Invalid value for `is_sending_blocked`, must not be `None`")  # noqa: E501

        self._is_sending_blocked = is_sending_blocked

    @property
    def bounce_count(self):
        """Gets the bounce_count of this AccountBounceBlockDto.  # noqa: E501


        :return: The bounce_count of this AccountBounceBlockDto.  # noqa: E501
        :rtype: int
        """
        return self._bounce_count

    @bounce_count.setter
    def bounce_count(self, bounce_count):
        """Sets the bounce_count of this AccountBounceBlockDto.


        :param bounce_count: The bounce_count of this AccountBounceBlockDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and bounce_count is None:  # noqa: E501
            raise ValueError("Invalid value for `bounce_count`, must not be `None`")  # noqa: E501

        self._bounce_count = bounce_count

    @property
    def bounce_count_today(self):
        """Gets the bounce_count_today of this AccountBounceBlockDto.  # noqa: E501


        :return: The bounce_count_today of this AccountBounceBlockDto.  # noqa: E501
        :rtype: int
        """
        return self._bounce_count_today

    @bounce_count_today.setter
    def bounce_count_today(self, bounce_count_today):
        """Sets the bounce_count_today of this AccountBounceBlockDto.


        :param bounce_count_today: The bounce_count_today of this AccountBounceBlockDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and bounce_count_today is None:  # noqa: E501
            raise ValueError("Invalid value for `bounce_count_today`, must not be `None`")  # noqa: E501

        self._bounce_count_today = bounce_count_today

    @property
    def maximum_daily_bounces(self):
        """Gets the maximum_daily_bounces of this AccountBounceBlockDto.  # noqa: E501


        :return: The maximum_daily_bounces of this AccountBounceBlockDto.  # noqa: E501
        :rtype: int
        """
        return self._maximum_daily_bounces

    @maximum_daily_bounces.setter
    def maximum_daily_bounces(self, maximum_daily_bounces):
        """Sets the maximum_daily_bounces of this AccountBounceBlockDto.


        :param maximum_daily_bounces: The maximum_daily_bounces of this AccountBounceBlockDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and maximum_daily_bounces is None:  # noqa: E501
            raise ValueError("Invalid value for `maximum_daily_bounces`, must not be `None`")  # noqa: E501

        self._maximum_daily_bounces = maximum_daily_bounces

    @property
    def maximum_account_bounces(self):
        """Gets the maximum_account_bounces of this AccountBounceBlockDto.  # noqa: E501


        :return: The maximum_account_bounces of this AccountBounceBlockDto.  # noqa: E501
        :rtype: int
        """
        return self._maximum_account_bounces

    @maximum_account_bounces.setter
    def maximum_account_bounces(self, maximum_account_bounces):
        """Sets the maximum_account_bounces of this AccountBounceBlockDto.


        :param maximum_account_bounces: The maximum_account_bounces of this AccountBounceBlockDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and maximum_account_bounces is None:  # noqa: E501
            raise ValueError("Invalid value for `maximum_account_bounces`, must not be `None`")  # noqa: E501

        self._maximum_account_bounces = maximum_account_bounces

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccountBounceBlockDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AccountBounceBlockDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class TenantReputationStatusRowDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_region': 'str',
        'tenant_name': 'str',
        'tenant_arn': 'str',
        'sending_status': 'str',
        'reputation_status': 'str',
        'reputation_policy': 'str',
        'customer_managed_sending_status': 'str',
        'aws_managed_sending_status': 'str',
        'finding_count': 'int',
        'bounce_rate': 'float',
        'complaint_rate': 'float',
        'send_last_hour': 'float',
        'metric_timestamp': 'datetime',
        'error': 'str'
    }

    attribute_map = {
        'account_region': 'accountRegion',
        'tenant_name': 'tenantName',
        'tenant_arn': 'tenantArn',
        'sending_status': 'sendingStatus',
        'reputation_status': 'reputationStatus',
        'reputation_policy': 'reputationPolicy',
        'customer_managed_sending_status': 'customerManagedSendingStatus',
        'aws_managed_sending_status': 'awsManagedSendingStatus',
        'finding_count': 'findingCount',
        'bounce_rate': 'bounceRate',
        'complaint_rate': 'complaintRate',
        'send_last_hour': 'sendLastHour',
        'metric_timestamp': 'metricTimestamp',
        'error': 'error'
    }

    def __init__(self, account_region=None, tenant_name=None, tenant_arn=None, sending_status=None, reputation_status=None, reputation_policy=None, customer_managed_sending_status=None, aws_managed_sending_status=None, finding_count=None, bounce_rate=None, complaint_rate=None, send_last_hour=None, metric_timestamp=None, error=None, local_vars_configuration=None):  # noqa: E501
        """TenantReputationStatusRowDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_region = None
        self._tenant_name = None
        self._tenant_arn = None
        self._sending_status = None
        self._reputation_status = None
        self._reputation_policy = None
        self._customer_managed_sending_status = None
        self._aws_managed_sending_status = None
        self._finding_count = None
        self._bounce_rate = None
        self._complaint_rate = None
        self._send_last_hour = None
        self._metric_timestamp = None
        self._error = None
        self.discriminator = None

        self.account_region = account_region
        self.tenant_name = tenant_name
        if tenant_arn is not None:
            self.tenant_arn = tenant_arn
        if sending_status is not None:
            self.sending_status = sending_status
        if reputation_status is not None:
            self.reputation_status = reputation_status
        if reputation_policy is not None:
            self.reputation_policy = reputation_policy
        if customer_managed_sending_status is not None:
            self.customer_managed_sending_status = customer_managed_sending_status
        if aws_managed_sending_status is not None:
            self.aws_managed_sending_status = aws_managed_sending_status
        self.finding_count = finding_count
        if bounce_rate is not None:
            self.bounce_rate = bounce_rate
        if complaint_rate is not None:
            self.complaint_rate = complaint_rate
        if send_last_hour is not None:
            self.send_last_hour = send_last_hour
        if metric_timestamp is not None:
            self.metric_timestamp = metric_timestamp
        if error is not None:
            self.error = error

    @property
    def account_region(self):
        """Gets the account_region of this TenantReputationStatusRowDto.  # noqa: E501


        :return: The account_region of this TenantReputationStatusRowDto.  # noqa: E501
        :rtype: str
        """
        return self._account_region

    @account_region.setter
    def account_region(self, account_region):
        """Sets the account_region of this TenantReputationStatusRowDto.


        :param account_region: The account_region of this TenantReputationStatusRowDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and account_region is None:  # noqa: E501
            raise ValueError("Invalid value for `account_region`, must not be `None`")  # noqa: E501
        allowed_values = ["US_WEST_2_ACCOUNT_STAGING", "US_EAST_1_ACCOUNT_STAGING", "EU_WEST_1_ACCOUNT_STAGING", "US_WEST_2_ACCOUNT_SES_1", "EU_WEST_1_ACCOUNT_SES_1", "US_WEST_2_ACCOUNT_SES_2", "EU_WEST_1_ACCOUNT_SES_2", "US_WEST_2_ACCOUNT_BYTEWISE", "EU_WEST_1_ACCOUNT_BYTEWISE", "US_WEST_2", "EU_WEST_1", "US_EAST_1"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and account_region not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `account_region` ({0}), must be one of {1}"  # noqa: E501
                .format(account_region, allowed_values)
            )

        self._account_region = account_region

    @property
    def tenant_name(self):
        """Gets the tenant_name of this TenantReputationStatusRowDto.  # noqa: E501


        :return: The tenant_name of this TenantReputationStatusRowDto.  # noqa: E501
        :rtype: str
        """
        return self._tenant_name

    @tenant_name.setter
    def tenant_name(self, tenant_name):
        """Sets the tenant_name of this TenantReputationStatusRowDto.


        :param tenant_name: The tenant_name of this TenantReputationStatusRowDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and tenant_name is None:  # noqa: E501
            raise ValueError("Invalid value for `tenant_name`, must not be `None`")  # noqa: E501

        self._tenant_name = tenant_name

    @property
    def tenant_arn(self):
        """Gets the tenant_arn of this TenantReputationStatusRowDto.  # noqa: E501


        :return: The tenant_arn of this TenantReputationStatusRowDto.  # noqa: E501
        :rtype: str
        """
        return self._tenant_arn

    @tenant_arn.setter
    def tenant_arn(self, tenant_arn):
        """Sets the tenant_arn of this TenantReputationStatusRowDto.


        :param tenant_arn: The tenant_arn of this TenantReputationStatusRowDto.  # noqa: E501
        :type: str
        """

        self._tenant_arn = tenant_arn

    @property
    def sending_status(self):
        """Gets the sending_status of this TenantReputationStatusRowDto.  # noqa: E501


        :return: The sending_status of this TenantReputationStatusRowDto.  # noqa: E501
        :rtype: str
        """
        return self._sending_status

    @sending_status.setter
    def sending_status(self, sending_status):
        """Sets the sending_status of this TenantReputationStatusRowDto.


        :param sending_status: The sending_status of this TenantReputationStatusRowDto.  # noqa: E501
        :type: str
        """

        self._sending_status = sending_status

    @property
    def reputation_status(self):
        """Gets the reputation_status of this TenantReputationStatusRowDto.  # noqa: E501


        :return: The reputation_status of this TenantReputationStatusRowDto.  # noqa: E501
        :rtype: str
        """
        return self._reputation_status

    @reputation_status.setter
    def reputation_status(self, reputation_status):
        """Sets the reputation_status of this TenantReputationStatusRowDto.


        :param reputation_status: The reputation_status of this TenantReputationStatusRowDto.  # noqa: E501
        :type: str
        """

        self._reputation_status = reputation_status

    @property
    def reputation_policy(self):
        """Gets the reputation_policy of this TenantReputationStatusRowDto.  # noqa: E501


        :return: The reputation_policy of this TenantReputationStatusRowDto.  # noqa: E501
        :rtype: str
        """
        return self._reputation_policy

    @reputation_policy.setter
    def reputation_policy(self, reputation_policy):
        """Sets the reputation_policy of this TenantReputationStatusRowDto.


        :param reputation_policy: The reputation_policy of this TenantReputationStatusRowDto.  # noqa: E501
        :type: str
        """

        self._reputation_policy = reputation_policy

    @property
    def customer_managed_sending_status(self):
        """Gets the customer_managed_sending_status of this TenantReputationStatusRowDto.  # noqa: E501


        :return: The customer_managed_sending_status of this TenantReputationStatusRowDto.  # noqa: E501
        :rtype: str
        """
        return self._customer_managed_sending_status

    @customer_managed_sending_status.setter
    def customer_managed_sending_status(self, customer_managed_sending_status):
        """Sets the customer_managed_sending_status of this TenantReputationStatusRowDto.


        :param customer_managed_sending_status: The customer_managed_sending_status of this TenantReputationStatusRowDto.  # noqa: E501
        :type: str
        """

        self._customer_managed_sending_status = customer_managed_sending_status

    @property
    def aws_managed_sending_status(self):
        """Gets the aws_managed_sending_status of this TenantReputationStatusRowDto.  # noqa: E501


        :return: The aws_managed_sending_status of this TenantReputationStatusRowDto.  # noqa: E501
        :rtype: str
        """
        return self._aws_managed_sending_status

    @aws_managed_sending_status.setter
    def aws_managed_sending_status(self, aws_managed_sending_status):
        """Sets the aws_managed_sending_status of this TenantReputationStatusRowDto.


        :param aws_managed_sending_status: The aws_managed_sending_status of this TenantReputationStatusRowDto.  # noqa: E501
        :type: str
        """

        self._aws_managed_sending_status = aws_managed_sending_status

    @property
    def finding_count(self):
        """Gets the finding_count of this TenantReputationStatusRowDto.  # noqa: E501


        :return: The finding_count of this TenantReputationStatusRowDto.  # noqa: E501
        :rtype: int
        """
        return self._finding_count

    @finding_count.setter
    def finding_count(self, finding_count):
        """Sets the finding_count of this TenantReputationStatusRowDto.


        :param finding_count: The finding_count of this TenantReputationStatusRowDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and finding_count is None:  # noqa: E501
            raise ValueError("Invalid value for `finding_count`, must not be `None`")  # noqa: E501

        self._finding_count = finding_count

    @property
    def bounce_rate(self):
        """Gets the bounce_rate of this TenantReputationStatusRowDto.  # noqa: E501


        :return: The bounce_rate of this TenantReputationStatusRowDto.  # noqa: E501
        :rtype: float
        """
        return self._bounce_rate

    @bounce_rate.setter
    def bounce_rate(self, bounce_rate):
        """Sets the bounce_rate of this TenantReputationStatusRowDto.


        :param bounce_rate: The bounce_rate of this TenantReputationStatusRowDto.  # noqa: E501
        :type: float
        """

        self._bounce_rate = bounce_rate

    @property
    def complaint_rate(self):
        """Gets the complaint_rate of this TenantReputationStatusRowDto.  # noqa: E501


        :return: The complaint_rate of this TenantReputationStatusRowDto.  # noqa: E501
        :rtype: float
        """
        return self._complaint_rate

    @complaint_rate.setter
    def complaint_rate(self, complaint_rate):
        """Sets the complaint_rate of this TenantReputationStatusRowDto.


        :param complaint_rate: The complaint_rate of this TenantReputationStatusRowDto.  # noqa: E501
        :type: float
        """

        self._complaint_rate = complaint_rate

    @property
    def send_last_hour(self):
        """Gets the send_last_hour of this TenantReputationStatusRowDto.  # noqa: E501


        :return: The send_last_hour of this TenantReputationStatusRowDto.  # noqa: E501
        :rtype: float
        """
        return self._send_last_hour

    @send_last_hour.setter
    def send_last_hour(self, send_last_hour):
        """Sets the send_last_hour of this TenantReputationStatusRowDto.


        :param send_last_hour: The send_last_hour of this TenantReputationStatusRowDto.  # noqa: E501
        :type: float
        """

        self._send_last_hour = send_last_hour

    @property
    def metric_timestamp(self):
        """Gets the metric_timestamp of this TenantReputationStatusRowDto.  # noqa: E501


        :return: The metric_timestamp of this TenantReputationStatusRowDto.  # noqa: E501
        :rtype: datetime
        """
        return self._metric_timestamp

    @metric_timestamp.setter
    def metric_timestamp(self, metric_timestamp):
        """Sets the metric_timestamp of this TenantReputationStatusRowDto.


        :param metric_timestamp: The metric_timestamp of this TenantReputationStatusRowDto.  # noqa: E501
        :type: datetime
        """

        self._metric_timestamp = metric_timestamp

    @property
    def error(self):
        """Gets the error of this TenantReputationStatusRowDto.  # noqa: E501


        :return: The error of this TenantReputationStatusRowDto.  # noqa: E501
        :rtype: str
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this TenantReputationStatusRowDto.


        :param error: The error of this TenantReputationStatusRowDto.  # noqa: E501
        :type: str
        """

        self._error = error

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TenantReputationStatusRowDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TenantReputationStatusRowDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.email_verification_controller_api import EmailVerificationControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestEmailVerificationControllerApi(unittest.TestCase):
    """EmailVerificationControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.email_verification_controller_api.EmailVerificationControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_all_validation_requests(self):
        """Test case for delete_all_validation_requests

        Delete all validation requests  # noqa: E501
        """
        pass

    def test_delete_validation_request(self):
        """Test case for delete_validation_request

        Delete a validation record  # noqa: E501
        """
        pass

    def test_get_email_intelligence(self):
        """Test case for get_email_intelligence

        Get intelligence score and breakdown for email/domain targets. Per unit billing for non-cached evaluations.  # noqa: E501
        """
        pass

    def test_get_validation_requests(self):
        """Test case for get_validation_requests

        Validate a list of email addresses. Per unit billing. See your plan for pricing.  # noqa: E501
        """
        pass

    def test_validate_email_address_list(self):
        """Test case for validate_email_address_list

        Validate a list of email addresses. Per unit billing. See your plan for pricing.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from mailslurp_client.api_client import ApiClient
from mailslurp_client.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class EmailAuditControllerApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def compare_email_audits(self, audit_id, other_audit_id, **kwargs):  # noqa: E501
        """Compare two email audits  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.compare_email_audits(audit_id, other_audit_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str audit_id: (required)
        :param str other_audit_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: EmailAuditComparisonDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.compare_email_audits_with_http_info(audit_id, other_audit_id, **kwargs)  # noqa: E501

    def compare_email_audits_with_http_info(self, audit_id, other_audit_id, **kwargs):  # noqa: E501
        """Compare two email audits  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.compare_email_audits_with_http_info(audit_id, other_audit_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str audit_id: (required)
        :param str other_audit_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(EmailAuditComparisonDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'audit_id',
            'other_audit_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method compare_email_audits" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'audit_id' is set
        if self.api_client.client_side_validation and ('audit_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['audit_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `audit_id` when calling `compare_email_audits`")  # noqa: E501
        # verify the required parameter 'other_audit_id' is set
        if self.api_client.client_side_validation and ('other_audit_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['other_audit_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `other_audit_id` when calling `compare_email_audits`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'audit_id' in local_var_params:
            path_params['auditId'] = local_var_params['audit_id']  # noqa: E501
        if 'other_audit_id' in local_var_params:
            path_params['otherAuditId'] = local_var_params['other_audit_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/email-audits/{auditId}/compare/{otherAuditId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='EmailAuditComparisonDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_email_audit(self, create_email_audit_options, **kwargs):  # noqa: E501
        """Create email audit  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_email_audit(create_email_audit_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreateEmailAuditOptions create_email_audit_options: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: EmailAuditDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_email_audit_with_http_info(create_email_audit_options, **kwargs)  # noqa: E501

    def create_email_audit_with_http_info(self, create_email_audit_options, **kwargs):  # noqa: E501
        """Create email audit  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_email_audit_with_http_info(create_email_audit_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreateEmailAuditOptions create_email_audit_options: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(EmailAuditDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'create_email_audit_options'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_email_audit" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'create_email_audit_options' is set
        if self.api_client.client_side_validation and ('create_email_audit_options' not in local_var_params or  # noqa: E501
                                                        local_var_params['create_email_audit_options'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `create_email_audit_options` when calling `create_email_audit`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_email_audit_options' in local_var_params:
            body_params = local_var_params['create_email_audit_options']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/email-audits', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='EmailAuditDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_email_audit(self, audit_id, **kwargs):  # noqa: E501
        """Delete email audit  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_email_audit(audit_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str audit_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_email_audit_with_http_info(audit_id, **kwargs)  # noqa: E501

    def delete_email_audit_with_http_info(self, audit_id, **kwargs):  # noqa: E501
        """Delete email audit  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_email_audit_with_http_info(audit_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str audit_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'audit_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_email_audit" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'audit_id' is set
        if self.api_client.client_side_validation and ('audit_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['audit_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `audit_id` when calling `delete_email_audit`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'audit_id' in local_var_params:
            path_params['auditId'] = local_var_params['audit_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/email-audits/{auditId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_email_audit(self, audit_id, **kwargs):  # noqa: E501
        """Get email audit  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_email_audit(audit_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str audit_id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: EmailAuditDto
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_email_audit_with_http_info(audit_id, **kwargs)  # noqa: E501

    def get_email_audit_with_http_info(self, audit_id, **kwargs):  # noqa: E501
        """Get email audit  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_email_audit_with_http_info(audit_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str audit_id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(EmailAuditDto, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'audit_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_email_audit" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'audit_id' is set
        if self.api_client.client_side_validation and ('audit_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['audit_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `audit_id` when calling `get_email_audit`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'audit_id' in local_var_params:
            path_params['auditId'] = local_var_params['audit_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/email-audits/{auditId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='EmailAuditDto',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_email_audits(self, **kwargs):  # noqa: E501
        """List email audits  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_email_audits(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str email_id:
        :param datetime since:
        :param datetime before:
        :param int limit:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[EmailAuditDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_email_audits_with_http_info(**kwargs)  # noqa: E501

    def get_email_audits_with_http_info(self, **kwargs):  # noqa: E501
        """List email audits  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_email_audits_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str email_id:
        :param datetime since:
        :param datetime before:
        :param int limit:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[EmailAuditDto], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'email_id',
            'since',
            'before',
            'limit'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_email_audits" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'email_id' in local_var_params and local_var_params['email_id'] is not None:  # noqa: E501
            query_params.append(('emailId', local_var_params['email_id']))  # noqa: E501
        if 'since' in local_var_params and local_var_params['since'] is not None:  # noqa: E501
            query_params.append(('since', local_var_params['since']))  # noqa: E501
        if 'before' in local_var_params and local_var_params['before'] is not None:  # noqa: E501
            query_params.append(('before', local_var_params['before']))  # noqa: E501
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['API_KEY']  # noqa: E501

        return self.api_client.call_api(
            '/email-audits', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[EmailAuditDto]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class PageComplaint(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'content': 'list[Complaint]',
        'pageable': 'PageableObject',
        'total_pages': 'int',
        'total_elements': 'int',
        'last': 'bool',
        'size': 'int',
        'number': 'int',
        'first': 'bool',
        'number_of_elements': 'int',
        'sort': 'SortObject',
        'empty': 'bool'
    }

    attribute_map = {
        'content': 'content',
        'pageable': 'pageable',
        'total_pages': 'totalPages',
        'total_elements': 'totalElements',
        'last': 'last',
        'size': 'size',
        'number': 'number',
        'first': 'first',
        'number_of_elements': 'numberOfElements',
        'sort': 'sort',
        'empty': 'empty'
    }

    def __init__(self, content=None, pageable=None, total_pages=None, total_elements=None, last=None, size=None, number=None, first=None, number_of_elements=None, sort=None, empty=None, local_vars_configuration=None):  # noqa: E501
        """PageComplaint - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._content = None
        self._pageable = None
        self._total_pages = None
        self._total_elements = None
        self._last = None
        self._size = None
        self._number = None
        self._first = None
        self._number_of_elements = None
        self._sort = None
        self._empty = None
        self.discriminator = None

        if content is not None:
            self.content = content
        if pageable is not None:
            self.pageable = pageable
        self.total_pages = total_pages
        self.total_elements = total_elements
        if last is not None:
            self.last = last
        if size is not None:
            self.size = size
        if number is not None:
            self.number = number
        if first is not None:
            self.first = first
        if number_of_elements is not None:
            self.number_of_elements = number_of_elements
        if sort is not None:
            self.sort = sort
        if empty is not None:
            self.empty = empty

    @property
    def content(self):
        """Gets the content of this PageComplaint.  # noqa: E501


        :return: The content of this PageComplaint.  # noqa: E501
        :rtype: list[Complaint]
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this PageComplaint.


        :param content: The content of this PageComplaint.  # noqa: E501
        :type: list[Complaint]
        """

        self._content = content

    @property
    def pageable(self):
        """Gets the pageable of this PageComplaint.  # noqa: E501


        :return: The pageable of this PageComplaint.  # noqa: E501
        :rtype: PageableObject
        """
        return self._pageable

    @pageable.setter
    def pageable(self, pageable):
        """Sets the pageable of this PageComplaint.


        :param pageable: The pageable of this PageComplaint.  # noqa: E501
        :type: PageableObject
        """

        self._pageable = pageable

    @property
    def total_pages(self):
        """Gets the total_pages of this PageComplaint.  # noqa: E501


        :return: The total_pages of this PageComplaint.  # noqa: E501
        :rtype: int
        """
        return self._total_pages

    @total_pages.setter
    def total_pages(self, total_pages):
        """Sets the total_pages of this PageComplaint.


        :param total_pages: The total_pages of this PageComplaint.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_pages is None:  # noqa: E501
            raise ValueError("Invalid value for `total_pages`, must not be `None`")  # noqa: E501

        self._total_pages = total_pages

    @property
    def total_elements(self):
        """Gets the total_elements of this PageComplaint.  # noqa: E501


        :return: The total_elements of this PageComplaint.  # noqa: E501
        :rtype: int
        """
        return self._total_elements

    @total_elements.setter
    def total_elements(self, total_elements):
        """Sets the total_elements of this PageComplaint.


        :param total_elements: The total_elements of this PageComplaint.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_elements is None:  # noqa: E501
            raise ValueError("Invalid value for `total_elements`, must not be `None`")  # noqa: E501

        self._total_elements = total_elements

    @property
    def last(self):
        """Gets the last of this PageComplaint.  # noqa: E501


        :return: The last of this PageComplaint.  # noqa: E501
        :rtype: bool
        """
        return self._last

    @last.setter
    def last(self, last):
        """Sets the last of this PageComplaint.


        :param last: The last of this PageComplaint.  # noqa: E501
        :type: bool
        """

        self._last = last

    @property
    def size(self):
        """Gets the size of this PageComplaint.  # noqa: E501


        :return: The size of this PageComplaint.  # noqa: E501
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this PageComplaint.


        :param size: The size of this PageComplaint.  # noqa: E501
        :type: int
        """

        self._size = size

    @property
    def number(self):
        """Gets the number of this PageComplaint.  # noqa: E501


        :return: The number of this PageComplaint.  # noqa: E501
        :rtype: int
        """
        return self._number

    @number.setter
    def number(self, number):
        """Sets the number of this PageComplaint.


        :param number: The number of this PageComplaint.  # noqa: E501
        :type: int
        """

        self._number = number

    @property
    def first(self):
        """Gets the first of this PageComplaint.  # noqa: E501


        :return: The first of this PageComplaint.  # noqa: E501
        :rtype: bool
        """
        return self._first

    @first.setter
    def first(self, first):
        """Sets the first of this PageComplaint.


        :param first: The first of this PageComplaint.  # noqa: E501
        :type: bool
        """

        self._first = first

    @property
    def number_of_elements(self):
        """Gets the number_of_elements of this PageComplaint.  # noqa: E501


        :return: The number_of_elements of this PageComplaint.  # noqa: E501
        :rtype: int
        """
        return self._number_of_elements

    @number_of_elements.setter
    def number_of_elements(self, number_of_elements):
        """Sets the number_of_elements of this PageComplaint.


        :param number_of_elements: The number_of_elements of this PageComplaint.  # noqa: E501
        :type: int
        """

        self._number_of_elements = number_of_elements

    @property
    def sort(self):
        """Gets the sort of this PageComplaint.  # noqa: E501


        :return: The sort of this PageComplaint.  # noqa: E501
        :rtype: SortObject
        """
        return self._sort

    @sort.setter
    def sort(self, sort):
        """Sets the sort of this PageComplaint.


        :param sort: The sort of this PageComplaint.  # noqa: E501
        :type: SortObject
        """

        self._sort = sort

    @property
    def empty(self):
        """Gets the empty of this PageComplaint.  # noqa: E501


        :return: The empty of this PageComplaint.  # noqa: E501
        :rtype: bool
        """
        return self._empty

    @empty.setter
    def empty(self, empty):
        """Sets the empty of this PageComplaint.


        :param empty: The empty of this PageComplaint.  # noqa: E501
        :type: bool
        """

        self._empty = empty

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PageComplaint):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PageComplaint):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CampaignProbeInsightsDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'probe_id': 'str',
        'since': 'datetime',
        'before': 'datetime',
        'total_runs': 'int',
        'healthy_runs': 'int',
        'warning_runs': 'int',
        'failed_runs': 'int',
        'success_rate': 'float',
        'average_health_score': 'float',
        'current_healthy_streak': 'int',
        'best_healthy_streak': 'int',
        'good_performance_signals': 'list[str]',
        'attention_signals': 'list[str]',
        'top_findings': 'list[str]',
        'latest_run': 'CampaignProbeRunDto'
    }

    attribute_map = {
        'probe_id': 'probeId',
        'since': 'since',
        'before': 'before',
        'total_runs': 'totalRuns',
        'healthy_runs': 'healthyRuns',
        'warning_runs': 'warningRuns',
        'failed_runs': 'failedRuns',
        'success_rate': 'successRate',
        'average_health_score': 'averageHealthScore',
        'current_healthy_streak': 'currentHealthyStreak',
        'best_healthy_streak': 'bestHealthyStreak',
        'good_performance_signals': 'goodPerformanceSignals',
        'attention_signals': 'attentionSignals',
        'top_findings': 'topFindings',
        'latest_run': 'latestRun'
    }

    def __init__(self, probe_id=None, since=None, before=None, total_runs=None, healthy_runs=None, warning_runs=None, failed_runs=None, success_rate=None, average_health_score=None, current_healthy_streak=None, best_healthy_streak=None, good_performance_signals=None, attention_signals=None, top_findings=None, latest_run=None, local_vars_configuration=None):  # noqa: E501
        """CampaignProbeInsightsDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._probe_id = None
        self._since = None
        self._before = None
        self._total_runs = None
        self._healthy_runs = None
        self._warning_runs = None
        self._failed_runs = None
        self._success_rate = None
        self._average_health_score = None
        self._current_healthy_streak = None
        self._best_healthy_streak = None
        self._good_performance_signals = None
        self._attention_signals = None
        self._top_findings = None
        self._latest_run = None
        self.discriminator = None

        self.probe_id = probe_id
        self.since = since
        self.before = before
        self.total_runs = total_runs
        self.healthy_runs = healthy_runs
        self.warning_runs = warning_runs
        self.failed_runs = failed_runs
        self.success_rate = success_rate
        self.average_health_score = average_health_score
        self.current_healthy_streak = current_healthy_streak
        self.best_healthy_streak = best_healthy_streak
        self.good_performance_signals = good_performance_signals
        self.attention_signals = attention_signals
        self.top_findings = top_findings
        if latest_run is not None:
            self.latest_run = latest_run

    @property
    def probe_id(self):
        """Gets the probe_id of this CampaignProbeInsightsDto.  # noqa: E501


        :return: The probe_id of this CampaignProbeInsightsDto.  # noqa: E501
        :rtype: str
        """
        return self._probe_id

    @probe_id.setter
    def probe_id(self, probe_id):
        """Sets the probe_id of this CampaignProbeInsightsDto.


        :param probe_id: The probe_id of this CampaignProbeInsightsDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and probe_id is None:  # noqa: E501
            raise ValueError("Invalid value for `probe_id`, must not be `None`")  # noqa: E501

        self._probe_id = probe_id

    @property
    def since(self):
        """Gets the since of this CampaignProbeInsightsDto.  # noqa: E501


        :return: The since of this CampaignProbeInsightsDto.  # noqa: E501
        :rtype: datetime
        """
        return self._since

    @since.setter
    def since(self, since):
        """Sets the since of this CampaignProbeInsightsDto.


        :param since: The since of this CampaignProbeInsightsDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and since is None:  # noqa: E501
            raise ValueError("Invalid value for `since`, must not be `None`")  # noqa: E501

        self._since = since

    @property
    def before(self):
        """Gets the before of this CampaignProbeInsightsDto.  # noqa: E501


        :return: The before of this CampaignProbeInsightsDto.  # noqa: E501
        :rtype: datetime
        """
        return self._before

    @before.setter
    def before(self, before):
        """Sets the before of this CampaignProbeInsightsDto.


        :param before: The before of this CampaignProbeInsightsDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and before is None:  # noqa: E501
            raise ValueError("Invalid value for `before`, must not be `None`")  # noqa: E501

        self._before = before

    @property
    def total_runs(self):
        """Gets the total_runs of this CampaignProbeInsightsDto.  # noqa: E501


        :return: The total_runs of this CampaignProbeInsightsDto.  # noqa: E501
        :rtype: int
        """
        return self._total_runs

    @total_runs.setter
    def total_runs(self, total_runs):
        """Sets the total_runs of this CampaignProbeInsightsDto.


        :param total_runs: The total_runs of this CampaignProbeInsightsDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and total_runs is None:  # noqa: E501
            raise ValueError("Invalid value for `total_runs`, must not be `None`")  # noqa: E501

        self._total_runs = total_runs

    @property
    def healthy_runs(self):
        """Gets the healthy_runs of this CampaignProbeInsightsDto.  # noqa: E501


        :return: The healthy_runs of this CampaignProbeInsightsDto.  # noqa: E501
        :rtype: int
        """
        return self._healthy_runs

    @healthy_runs.setter
    def healthy_runs(self, healthy_runs):
        """Sets the healthy_runs of this CampaignProbeInsightsDto.


        :param healthy_runs: The healthy_runs of this CampaignProbeInsightsDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and healthy_runs is None:  # noqa: E501
            raise ValueError("Invalid value for `healthy_runs`, must not be `None`")  # noqa: E501

        self._healthy_runs = healthy_runs

    @property
    def warning_runs(self):
        """Gets the warning_runs of this CampaignProbeInsightsDto.  # noqa: E501


        :return: The warning_runs of this CampaignProbeInsightsDto.  # noqa: E501
        :rtype: int
        """
        return self._warning_runs

    @warning_runs.setter
    def warning_runs(self, warning_runs):
        """Sets the warning_runs of this CampaignProbeInsightsDto.


        :param warning_runs: The warning_runs of this CampaignProbeInsightsDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and warning_runs is None:  # noqa: E501
            raise ValueError("Invalid value for `warning_runs`, must not be `None`")  # noqa: E501

        self._warning_runs = warning_runs

    @property
    def failed_runs(self):
        """Gets the failed_runs of this CampaignProbeInsightsDto.  # noqa: E501


        :return: The failed_runs of this CampaignProbeInsightsDto.  # noqa: E501
        :rtype: int
        """
        return self._failed_runs

    @failed_runs.setter
    def failed_runs(self, failed_runs):
        """Sets the failed_runs of this CampaignProbeInsightsDto.


        :param failed_runs: The failed_runs of this CampaignProbeInsightsDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and failed_runs is None:  # noqa: E501
            raise ValueError("Invalid value for `failed_runs`, must not be `None`")  # noqa: E501

        self._failed_runs = failed_runs

    @property
    def success_rate(self):
        """Gets the success_rate of this CampaignProbeInsightsDto.  # noqa: E501


        :return: The success_rate of this CampaignProbeInsightsDto.  # noqa: E501
        :rtype: float
        """
        return self._success_rate

    @success_rate.setter
    def success_rate(self, success_rate):
        """Sets the success_rate of this CampaignProbeInsightsDto.


        :param success_rate: The success_rate of this CampaignProbeInsightsDto.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and success_rate is None:  # noqa: E501
            raise ValueError("Invalid value for `success_rate`, must not be `None`")  # noqa: E501

        self._success_rate = success_rate

    @property
    def average_health_score(self):
        """Gets the average_health_score of this CampaignProbeInsightsDto.  # noqa: E501


        :return: The average_health_score of this CampaignProbeInsightsDto.  # noqa: E501
        :rtype: float
        """
        return self._average_health_score

    @average_health_score.setter
    def average_health_score(self, average_health_score):
        """Sets the average_health_score of this CampaignProbeInsightsDto.


        :param average_health_score: The average_health_score of this CampaignProbeInsightsDto.  # noqa: E501
        :type: float
        """
        if self.local_vars_configuration.client_side_validation and average_health_score is None:  # noqa: E501
            raise ValueError("Invalid value for `average_health_score`, must not be `None`")  # noqa: E501

        self._average_health_score = average_health_score

    @property
    def current_healthy_streak(self):
        """Gets the current_healthy_streak of this CampaignProbeInsightsDto.  # noqa: E501


        :return: The current_healthy_streak of this CampaignProbeInsightsDto.  # noqa: E501
        :rtype: int
        """
        return self._current_healthy_streak

    @current_healthy_streak.setter
    def current_healthy_streak(self, current_healthy_streak):
        """Sets the current_healthy_streak of this CampaignProbeInsightsDto.


        :param current_healthy_streak: The current_healthy_streak of this CampaignProbeInsightsDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and current_healthy_streak is None:  # noqa: E501
            raise ValueError("Invalid value for `current_healthy_streak`, must not be `None`")  # noqa: E501

        self._current_healthy_streak = current_healthy_streak

    @property
    def best_healthy_streak(self):
        """Gets the best_healthy_streak of this CampaignProbeInsightsDto.  # noqa: E501


        :return: The best_healthy_streak of this CampaignProbeInsightsDto.  # noqa: E501
        :rtype: int
        """
        return self._best_healthy_streak

    @best_healthy_streak.setter
    def best_healthy_streak(self, best_healthy_streak):
        """Sets the best_healthy_streak of this CampaignProbeInsightsDto.


        :param best_healthy_streak: The best_healthy_streak of this CampaignProbeInsightsDto.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and best_healthy_streak is None:  # noqa: E501
            raise ValueError("Invalid value for `best_healthy_streak`, must not be `None`")  # noqa: E501

        self._best_healthy_streak = best_healthy_streak

    @property
    def good_performance_signals(self):
        """Gets the good_performance_signals of this CampaignProbeInsightsDto.  # noqa: E501


        :return: The good_performance_signals of this CampaignProbeInsightsDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._good_performance_signals

    @good_performance_signals.setter
    def good_performance_signals(self, good_performance_signals):
        """Sets the good_performance_signals of this CampaignProbeInsightsDto.


        :param good_performance_signals: The good_performance_signals of this CampaignProbeInsightsDto.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and good_performance_signals is None:  # noqa: E501
            raise ValueError("Invalid value for `good_performance_signals`, must not be `None`")  # noqa: E501

        self._good_performance_signals = good_performance_signals

    @property
    def attention_signals(self):
        """Gets the attention_signals of this CampaignProbeInsightsDto.  # noqa: E501


        :return: The attention_signals of this CampaignProbeInsightsDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._attention_signals

    @attention_signals.setter
    def attention_signals(self, attention_signals):
        """Sets the attention_signals of this CampaignProbeInsightsDto.


        :param attention_signals: The attention_signals of this CampaignProbeInsightsDto.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and attention_signals is None:  # noqa: E501
            raise ValueError("Invalid value for `attention_signals`, must not be `None`")  # noqa: E501

        self._attention_signals = attention_signals

    @property
    def top_findings(self):
        """Gets the top_findings of this CampaignProbeInsightsDto.  # noqa: E501


        :return: The top_findings of this CampaignProbeInsightsDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._top_findings

    @top_findings.setter
    def top_findings(self, top_findings):
        """Sets the top_findings of this CampaignProbeInsightsDto.


        :param top_findings: The top_findings of this CampaignProbeInsightsDto.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and top_findings is None:  # noqa: E501
            raise ValueError("Invalid value for `top_findings`, must not be `None`")  # noqa: E501

        self._top_findings = top_findings

    @property
    def latest_run(self):
        """Gets the latest_run of this CampaignProbeInsightsDto.  # noqa: E501


        :return: The latest_run of this CampaignProbeInsightsDto.  # noqa: E501
        :rtype: CampaignProbeRunDto
        """
        return self._latest_run

    @latest_run.setter
    def latest_run(self, latest_run):
        """Sets the latest_run of this CampaignProbeInsightsDto.


        :param latest_run: The latest_run of this CampaignProbeInsightsDto.  # noqa: E501
        :type: CampaignProbeRunDto
        """

        self._latest_run = latest_run

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CampaignProbeInsightsDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CampaignProbeInsightsDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class CreateConnectorOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'email_address': 'str',
        'enabled': 'bool'
    }

    attribute_map = {
        'name': 'name',
        'email_address': 'emailAddress',
        'enabled': 'enabled'
    }

    def __init__(self, name=None, email_address=None, enabled=None, local_vars_configuration=None):  # noqa: E501
        """CreateConnectorOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._email_address = None
        self._enabled = None
        self.discriminator = None

        self.name = name
        self.email_address = email_address
        self.enabled = enabled

    @property
    def name(self):
        """Gets the name of this CreateConnectorOptions.  # noqa: E501

        Name of connector  # noqa: E501

        :return: The name of this CreateConnectorOptions.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CreateConnectorOptions.

        Name of connector  # noqa: E501

        :param name: The name of this CreateConnectorOptions.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def email_address(self):
        """Gets the email_address of this CreateConnectorOptions.  # noqa: E501

        Email address of external inbox  # noqa: E501

        :return: The email_address of this CreateConnectorOptions.  # noqa: E501
        :rtype: str
        """
        return self._email_address

    @email_address.setter
    def email_address(self, email_address):
        """Sets the email_address of this CreateConnectorOptions.

        Email address of external inbox  # noqa: E501

        :param email_address: The email_address of this CreateConnectorOptions.  # noqa: E501
        :type: str
        """

        self._email_address = email_address

    @property
    def enabled(self):
        """Gets the enabled of this CreateConnectorOptions.  # noqa: E501

        Is connector enabled  # noqa: E501

        :return: The enabled of this CreateConnectorOptions.  # noqa: E501
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """Sets the enabled of this CreateConnectorOptions.

        Is connector enabled  # noqa: E501

        :param enabled: The enabled of this CreateConnectorOptions.  # noqa: E501
        :type: bool
        """

        self._enabled = enabled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateConnectorOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateConnectorOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class EmailAuditDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'user_id': 'str',
        'email_id': 'str',
        'from_address': 'str',
        'recipient': 'str',
        'subject': 'str',
        'analysis': 'EmailAuditAnalysisResult',
        'created_at': 'datetime',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'user_id': 'userId',
        'email_id': 'emailId',
        'from_address': 'fromAddress',
        'recipient': 'recipient',
        'subject': 'subject',
        'analysis': 'analysis',
        'created_at': 'createdAt',
        'updated_at': 'updatedAt'
    }

    def __init__(self, id=None, user_id=None, email_id=None, from_address=None, recipient=None, subject=None, analysis=None, created_at=None, updated_at=None, local_vars_configuration=None):  # noqa: E501
        """EmailAuditDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._user_id = None
        self._email_id = None
        self._from_address = None
        self._recipient = None
        self._subject = None
        self._analysis = None
        self._created_at = None
        self._updated_at = None
        self.discriminator = None

        self.id = id
        self.user_id = user_id
        self.email_id = email_id
        self.from_address = from_address
        self.recipient = recipient
        self.subject = subject
        self.analysis = analysis
        self.created_at = created_at
        self.updated_at = updated_at

    @property
    def id(self):
        """Gets the id of this EmailAuditDto.  # noqa: E501


        :return: The id of this EmailAuditDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this EmailAuditDto.


        :param id: The id of this EmailAuditDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def user_id(self):
        """Gets the user_id of this EmailAuditDto.  # noqa: E501


        :return: The user_id of this EmailAuditDto.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this EmailAuditDto.


        :param user_id: The user_id of this EmailAuditDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def email_id(self):
        """Gets the email_id of this EmailAuditDto.  # noqa: E501


        :return: The email_id of this EmailAuditDto.  # noqa: E501
        :rtype: str
        """
        return self._email_id

    @email_id.setter
    def email_id(self, email_id):
        """Sets the email_id of this EmailAuditDto.


        :param email_id: The email_id of this EmailAuditDto.  # noqa: E501
        :type: str
        """

        self._email_id = email_id

    @property
    def from_address(self):
        """Gets the from_address of this EmailAuditDto.  # noqa: E501


        :return: The from_address of this EmailAuditDto.  # noqa: E501
        :rtype: str
        """
        return self._from_address

    @from_address.setter
    def from_address(self, from_address):
        """Sets the from_address of this EmailAuditDto.


        :param from_address: The from_address of this EmailAuditDto.  # noqa: E501
        :type: str
        """

        self._from_address = from_address

    @property
    def recipient(self):
        """Gets the recipient of this EmailAuditDto.  # noqa: E501


        :return: The recipient of this EmailAuditDto.  # noqa: E501
        :rtype: str
        """
        return self._recipient

    @recipient.setter
    def recipient(self, recipient):
        """Sets the recipient of this EmailAuditDto.


        :param recipient: The recipient of this EmailAuditDto.  # noqa: E501
        :type: str
        """

        self._recipient = recipient

    @property
    def subject(self):
        """Gets the subject of this EmailAuditDto.  # noqa: E501


        :return: The subject of this EmailAuditDto.  # noqa: E501
        :rtype: str
        """
        return self._subject

    @subject.setter
    def subject(self, subject):
        """Sets the subject of this EmailAuditDto.


        :param subject: The subject of this EmailAuditDto.  # noqa: E501
        :type: str
        """

        self._subject = subject

    @property
    def analysis(self):
        """Gets the analysis of this EmailAuditDto.  # noqa: E501


        :return: The analysis of this EmailAuditDto.  # noqa: E501
        :rtype: EmailAuditAnalysisResult
        """
        return self._analysis

    @analysis.setter
    def analysis(self, analysis):
        """Sets the analysis of this EmailAuditDto.


        :param analysis: The analysis of this EmailAuditDto.  # noqa: E501
        :type: EmailAuditAnalysisResult
        """
        if self.local_vars_configuration.client_side_validation and analysis is None:  # noqa: E501
            raise ValueError("Invalid value for `analysis`, must not be `None`")  # noqa: E501

        self._analysis = analysis

    @property
    def created_at(self):
        """Gets the created_at of this EmailAuditDto.  # noqa: E501


        :return: The created_at of this EmailAuditDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this EmailAuditDto.


        :param created_at: The created_at of this EmailAuditDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def updated_at(self):
        """Gets the updated_at of this EmailAuditDto.  # noqa: E501


        :return: The updated_at of this EmailAuditDto.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at):
        """Sets the updated_at of this EmailAuditDto.


        :param updated_at: The updated_at of this EmailAuditDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and updated_at is None:  # noqa: E501
            raise ValueError("Invalid value for `updated_at`, must not be `None`")  # noqa: E501

        self._updated_at = updated_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailAuditDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EmailAuditDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mailslurp_client
from mailslurp_client.api.device_previews_controller_api import DevicePreviewsControllerApi  # noqa: E501
from mailslurp_client.rest import ApiException


class TestDevicePreviewsControllerApi(unittest.TestCase):
    """DevicePreviewsControllerApi unit test stubs"""

    def setUp(self):
        self.api = mailslurp_client.api.device_previews_controller_api.DevicePreviewsControllerApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_cancel_device_preview_run(self):
        """Test case for cancel_device_preview_run

        Cancel a running device preview run  # noqa: E501
        """
        pass

    def test_create_device_preview_feedback(self):
        """Test case for create_device_preview_feedback

        Create device preview feedback  # noqa: E501
        """
        pass

    def test_create_device_preview_run(self):
        """Test case for create_device_preview_run

        Create a new device preview run for an email  # noqa: E501
        """
        pass

    def test_delete_device_preview_run(self):
        """Test case for delete_device_preview_run

        Delete local device preview run data  # noqa: E501
        """
        pass

    def test_ensure_device_preview_run(self):
        """Test case for ensure_device_preview_run

        Return active run for email or create one when none exists  # noqa: E501
        """
        pass

    def test_get_device_preview_feedback(self):
        """Test case for get_device_preview_feedback

        Get a single device preview feedback item  # noqa: E501
        """
        pass

    def test_get_device_preview_feedback_items(self):
        """Test case for get_device_preview_feedback_items

        List device preview feedback  # noqa: E501
        """
        pass

    def test_get_device_preview_run(self):
        """Test case for get_device_preview_run

        Get device preview run status  # noqa: E501
        """
        pass

    def test_get_device_preview_run_provider_progress(self):
        """Test case for get_device_preview_run_provider_progress

        Get provider-level progress for a device preview run  # noqa: E501
        """
        pass

    def test_get_device_preview_run_results(self):
        """Test case for get_device_preview_run_results

        Get device preview run results  # noqa: E501
        """
        pass

    def test_get_device_preview_run_screenshot(self):
        """Test case for get_device_preview_run_screenshot

        Get a seeded device preview screenshot image  # noqa: E501
        """
        pass

    def test_get_device_preview_runs(self):
        """Test case for get_device_preview_runs

        List previous device preview runs for an email  # noqa: E501
        """
        pass

    def test_get_device_preview_runs_for_account(self):
        """Test case for get_device_preview_runs_for_account

        List previous device preview runs for account  # noqa: E501
        """
        pass

    def test_get_device_preview_runs_offset_paginated(self):
        """Test case for get_device_preview_runs_offset_paginated

        List previous device preview runs for an email in paginated form  # noqa: E501
        """
        pass

    def test_update_device_preview_feedback(self):
        """Test case for update_device_preview_feedback

        Update device preview feedback  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class AITransformResultProjectionDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'ai_transform_id': 'str',
        'ai_transform_mapping_id': 'str',
        'user_id': 'str',
        'value': 'object',
        'entity_id': 'str',
        'entity_type': 'str',
        'sms_id': 'str',
        'email_id': 'str',
        'attachment_id': 'str',
        'created_at': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'ai_transform_id': 'aiTransformId',
        'ai_transform_mapping_id': 'aiTransformMappingId',
        'user_id': 'userId',
        'value': 'value',
        'entity_id': 'entityId',
        'entity_type': 'entityType',
        'sms_id': 'smsId',
        'email_id': 'emailId',
        'attachment_id': 'attachmentId',
        'created_at': 'createdAt'
    }

    def __init__(self, id=None, ai_transform_id=None, ai_transform_mapping_id=None, user_id=None, value=None, entity_id=None, entity_type=None, sms_id=None, email_id=None, attachment_id=None, created_at=None, local_vars_configuration=None):  # noqa: E501
        """AITransformResultProjectionDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._ai_transform_id = None
        self._ai_transform_mapping_id = None
        self._user_id = None
        self._value = None
        self._entity_id = None
        self._entity_type = None
        self._sms_id = None
        self._email_id = None
        self._attachment_id = None
        self._created_at = None
        self.discriminator = None

        self.id = id
        self.ai_transform_id = ai_transform_id
        self.ai_transform_mapping_id = ai_transform_mapping_id
        self.user_id = user_id
        self.value = value
        self.entity_id = entity_id
        self.entity_type = entity_type
        self.sms_id = sms_id
        self.email_id = email_id
        self.attachment_id = attachment_id
        self.created_at = created_at

    @property
    def id(self):
        """Gets the id of this AITransformResultProjectionDto.  # noqa: E501


        :return: The id of this AITransformResultProjectionDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AITransformResultProjectionDto.


        :param id: The id of this AITransformResultProjectionDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def ai_transform_id(self):
        """Gets the ai_transform_id of this AITransformResultProjectionDto.  # noqa: E501


        :return: The ai_transform_id of this AITransformResultProjectionDto.  # noqa: E501
        :rtype: str
        """
        return self._ai_transform_id

    @ai_transform_id.setter
    def ai_transform_id(self, ai_transform_id):
        """Sets the ai_transform_id of this AITransformResultProjectionDto.


        :param ai_transform_id: The ai_transform_id of this AITransformResultProjectionDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and ai_transform_id is None:  # noqa: E501
            raise ValueError("Invalid value for `ai_transform_id`, must not be `None`")  # noqa: E501

        self._ai_transform_id = ai_transform_id

    @property
    def ai_transform_mapping_id(self):
        """Gets the ai_transform_mapping_id of this AITransformResultProjectionDto.  # noqa: E501


        :return: The ai_transform_mapping_id of this AITransformResultProjectionDto.  # noqa: E501
        :rtype: str
        """
        return self._ai_transform_mapping_id

    @ai_transform_mapping_id.setter
    def ai_transform_mapping_id(self, ai_transform_mapping_id):
        """Sets the ai_transform_mapping_id of this AITransformResultProjectionDto.


        :param ai_transform_mapping_id: The ai_transform_mapping_id of this AITransformResultProjectionDto.  # noqa: E501
        :type: str
        """

        self._ai_transform_mapping_id = ai_transform_mapping_id

    @property
    def user_id(self):
        """Gets the user_id of this AITransformResultProjectionDto.  # noqa: E501


        :return: The user_id of this AITransformResultProjectionDto.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this AITransformResultProjectionDto.


        :param user_id: The user_id of this AITransformResultProjectionDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def value(self):
        """Gets the value of this AITransformResultProjectionDto.  # noqa: E501


        :return: The value of this AITransformResultProjectionDto.  # noqa: E501
        :rtype: object
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this AITransformResultProjectionDto.


        :param value: The value of this AITransformResultProjectionDto.  # noqa: E501
        :type: object
        """

        self._value = value

    @property
    def entity_id(self):
        """Gets the entity_id of this AITransformResultProjectionDto.  # noqa: E501


        :return: The entity_id of this AITransformResultProjectionDto.  # noqa: E501
        :rtype: str
        """
        return self._entity_id

    @entity_id.setter
    def entity_id(self, entity_id):
        """Sets the entity_id of this AITransformResultProjectionDto.


        :param entity_id: The entity_id of this AITransformResultProjectionDto.  # noqa: E501
        :type: str
        """

        self._entity_id = entity_id

    @property
    def entity_type(self):
        """Gets the entity_type of this AITransformResultProjectionDto.  # noqa: E501


        :return: The entity_type of this AITransformResultProjectionDto.  # noqa: E501
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """Sets the entity_type of this AITransformResultProjectionDto.


        :param entity_type: The entity_type of this AITransformResultProjectionDto.  # noqa: E501
        :type: str
        """
        allowed_values = [None,"INBOX", "PHONE"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and entity_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `entity_type` ({0}), must be one of {1}"  # noqa: E501
                .format(entity_type, allowed_values)
            )

        self._entity_type = entity_type

    @property
    def sms_id(self):
        """Gets the sms_id of this AITransformResultProjectionDto.  # noqa: E501


        :return: The sms_id of this AITransformResultProjectionDto.  # noqa: E501
        :rtype: str
        """
        return self._sms_id

    @sms_id.setter
    def sms_id(self, sms_id):
        """Sets the sms_id of this AITransformResultProjectionDto.


        :param sms_id: The sms_id of this AITransformResultProjectionDto.  # noqa: E501
        :type: str
        """

        self._sms_id = sms_id

    @property
    def email_id(self):
        """Gets the email_id of this AITransformResultProjectionDto.  # noqa: E501


        :return: The email_id of this AITransformResultProjectionDto.  # noqa: E501
        :rtype: str
        """
        return self._email_id

    @email_id.setter
    def email_id(self, email_id):
        """Sets the email_id of this AITransformResultProjectionDto.


        :param email_id: The email_id of this AITransformResultProjectionDto.  # noqa: E501
        :type: str
        """

        self._email_id = email_id

    @property
    def attachment_id(self):
        """Gets the attachment_id of this AITransformResultProjectionDto.  # noqa: E501


        :return: The attachment_id of this AITransformResultProjectionDto.  # noqa: E501
        :rtype: str
        """
        return self._attachment_id

    @attachment_id.setter
    def attachment_id(self, attachment_id):
        """Sets the attachment_id of this AITransformResultProjectionDto.


        :param attachment_id: The attachment_id of this AITransformResultProjectionDto.  # noqa: E501
        :type: str
        """

        self._attachment_id = attachment_id

    @property
    def created_at(self):
        """Gets the created_at of this AITransformResultProjectionDto.  # noqa: E501


        :return: The created_at of this AITransformResultProjectionDto.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this AITransformResultProjectionDto.


        :param created_at: The created_at of this AITransformResultProjectionDto.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AITransformResultProjectionDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AITransformResultProjectionDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class EntityFavouriteItemProjection(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'id': 'str',
        'description': 'str',
        'created_at': 'datetime',
        'entity_type': 'str'
    }

    attribute_map = {
        'name': 'name',
        'id': 'id',
        'description': 'description',
        'created_at': 'createdAt',
        'entity_type': 'entityType'
    }

    def __init__(self, name=None, id=None, description=None, created_at=None, entity_type=None, local_vars_configuration=None):  # noqa: E501
        """EntityFavouriteItemProjection - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._id = None
        self._description = None
        self._created_at = None
        self._entity_type = None
        self.discriminator = None

        self.name = name
        self.id = id
        if description is not None:
            self.description = description
        self.created_at = created_at
        self.entity_type = entity_type

    @property
    def name(self):
        """Gets the name of this EntityFavouriteItemProjection.  # noqa: E501


        :return: The name of this EntityFavouriteItemProjection.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this EntityFavouriteItemProjection.


        :param name: The name of this EntityFavouriteItemProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def id(self):
        """Gets the id of this EntityFavouriteItemProjection.  # noqa: E501


        :return: The id of this EntityFavouriteItemProjection.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this EntityFavouriteItemProjection.


        :param id: The id of this EntityFavouriteItemProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def description(self):
        """Gets the description of this EntityFavouriteItemProjection.  # noqa: E501


        :return: The description of this EntityFavouriteItemProjection.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this EntityFavouriteItemProjection.


        :param description: The description of this EntityFavouriteItemProjection.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def created_at(self):
        """Gets the created_at of this EntityFavouriteItemProjection.  # noqa: E501


        :return: The created_at of this EntityFavouriteItemProjection.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this EntityFavouriteItemProjection.


        :param created_at: The created_at of this EntityFavouriteItemProjection.  # noqa: E501
        :type: datetime
        """
        if self.local_vars_configuration.client_side_validation and created_at is None:  # noqa: E501
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def entity_type(self):
        """Gets the entity_type of this EntityFavouriteItemProjection.  # noqa: E501


        :return: The entity_type of this EntityFavouriteItemProjection.  # noqa: E501
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """Sets the entity_type of this EntityFavouriteItemProjection.


        :param entity_type: The entity_type of this EntityFavouriteItemProjection.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and entity_type is None:  # noqa: E501
            raise ValueError("Invalid value for `entity_type`, must not be `None`")  # noqa: E501
        allowed_values = ["INBOX", "EMAIL", "ATTACHMENT", "PHONE", "SMS"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and entity_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `entity_type` ({0}), must be one of {1}"  # noqa: E501
                .format(entity_type, allowed_values)
            )

        self._entity_type = entity_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EntityFavouriteItemProjection):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EntityFavouriteItemProjection):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class ImapMailboxStatus(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'read_only': 'bool',
        'items': 'object',
        'flags': 'list[str]',
        'permanent_flags': 'list[str]',
        'unseen_seq_num': 'int',
        'messages': 'int',
        'recent': 'int',
        'unseen': 'int',
        'uid_next': 'int',
        'uid_validity': 'int',
        'append_limit': 'int'
    }

    attribute_map = {
        'name': 'name',
        'read_only': 'readOnly',
        'items': 'items',
        'flags': 'flags',
        'permanent_flags': 'permanentFlags',
        'unseen_seq_num': 'unseenSeqNum',
        'messages': 'messages',
        'recent': 'recent',
        'unseen': 'unseen',
        'uid_next': 'uidNext',
        'uid_validity': 'uidValidity',
        'append_limit': 'appendLimit'
    }

    def __init__(self, name=None, read_only=None, items=None, flags=None, permanent_flags=None, unseen_seq_num=None, messages=None, recent=None, unseen=None, uid_next=None, uid_validity=None, append_limit=None, local_vars_configuration=None):  # noqa: E501
        """ImapMailboxStatus - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._read_only = None
        self._items = None
        self._flags = None
        self._permanent_flags = None
        self._unseen_seq_num = None
        self._messages = None
        self._recent = None
        self._unseen = None
        self._uid_next = None
        self._uid_validity = None
        self._append_limit = None
        self.discriminator = None

        self.name = name
        self.read_only = read_only
        self.items = items
        self.flags = flags
        self.permanent_flags = permanent_flags
        self.unseen_seq_num = unseen_seq_num
        self.messages = messages
        self.recent = recent
        self.unseen = unseen
        self.uid_next = uid_next
        self.uid_validity = uid_validity
        self.append_limit = append_limit

    @property
    def name(self):
        """Gets the name of this ImapMailboxStatus.  # noqa: E501

        The mailbox name.  # noqa: E501

        :return: The name of this ImapMailboxStatus.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ImapMailboxStatus.

        The mailbox name.  # noqa: E501

        :param name: The name of this ImapMailboxStatus.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def read_only(self):
        """Gets the read_only of this ImapMailboxStatus.  # noqa: E501

        True if the mailbox is open in read-only mode.  # noqa: E501

        :return: The read_only of this ImapMailboxStatus.  # noqa: E501
        :rtype: bool
        """
        return self._read_only

    @read_only.setter
    def read_only(self, read_only):
        """Sets the read_only of this ImapMailboxStatus.

        True if the mailbox is open in read-only mode.  # noqa: E501

        :param read_only: The read_only of this ImapMailboxStatus.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and read_only is None:  # noqa: E501
            raise ValueError("Invalid value for `read_only`, must not be `None`")  # noqa: E501

        self._read_only = read_only

    @property
    def items(self):
        """Gets the items of this ImapMailboxStatus.  # noqa: E501

        Results map  # noqa: E501

        :return: The items of this ImapMailboxStatus.  # noqa: E501
        :rtype: object
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this ImapMailboxStatus.

        Results map  # noqa: E501

        :param items: The items of this ImapMailboxStatus.  # noqa: E501
        :type: object
        """

        self._items = items

    @property
    def flags(self):
        """Gets the flags of this ImapMailboxStatus.  # noqa: E501

        The mailbox flags.  # noqa: E501

        :return: The flags of this ImapMailboxStatus.  # noqa: E501
        :rtype: list[str]
        """
        return self._flags

    @flags.setter
    def flags(self, flags):
        """Sets the flags of this ImapMailboxStatus.

        The mailbox flags.  # noqa: E501

        :param flags: The flags of this ImapMailboxStatus.  # noqa: E501
        :type: list[str]
        """

        self._flags = flags

    @property
    def permanent_flags(self):
        """Gets the permanent_flags of this ImapMailboxStatus.  # noqa: E501

        The mailbox permanent flags.  # noqa: E501

        :return: The permanent_flags of this ImapMailboxStatus.  # noqa: E501
        :rtype: list[str]
        """
        return self._permanent_flags

    @permanent_flags.setter
    def permanent_flags(self, permanent_flags):
        """Sets the permanent_flags of this ImapMailboxStatus.

        The mailbox permanent flags.  # noqa: E501

        :param permanent_flags: The permanent_flags of this ImapMailboxStatus.  # noqa: E501
        :type: list[str]
        """

        self._permanent_flags = permanent_flags

    @property
    def unseen_seq_num(self):
        """Gets the unseen_seq_num of this ImapMailboxStatus.  # noqa: E501

        The sequence number of the first unseen message in the mailbox.  # noqa: E501

        :return: The unseen_seq_num of this ImapMailboxStatus.  # noqa: E501
        :rtype: int
        """
        return self._unseen_seq_num

    @unseen_seq_num.setter
    def unseen_seq_num(self, unseen_seq_num):
        """Sets the unseen_seq_num of this ImapMailboxStatus.

        The sequence number of the first unseen message in the mailbox.  # noqa: E501

        :param unseen_seq_num: The unseen_seq_num of this ImapMailboxStatus.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and unseen_seq_num is None:  # noqa: E501
            raise ValueError("Invalid value for `unseen_seq_num`, must not be `None`")  # noqa: E501

        self._unseen_seq_num = unseen_seq_num

    @property
    def messages(self):
        """Gets the messages of this ImapMailboxStatus.  # noqa: E501

        The number of messages in this mailbox.  # noqa: E501

        :return: The messages of this ImapMailboxStatus.  # noqa: E501
        :rtype: int
        """
        return self._messages

    @messages.setter
    def messages(self, messages):
        """Sets the messages of this ImapMailboxStatus.

        The number of messages in this mailbox.  # noqa: E501

        :param messages: The messages of this ImapMailboxStatus.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and messages is None:  # noqa: E501
            raise ValueError("Invalid value for `messages`, must not be `None`")  # noqa: E501

        self._messages = messages

    @property
    def recent(self):
        """Gets the recent of this ImapMailboxStatus.  # noqa: E501

        The number of messages not seen since the last time the mailbox was opened.  # noqa: E501

        :return: The recent of this ImapMailboxStatus.  # noqa: E501
        :rtype: int
        """
        return self._recent

    @recent.setter
    def recent(self, recent):
        """Sets the recent of this ImapMailboxStatus.

        The number of messages not seen since the last time the mailbox was opened.  # noqa: E501

        :param recent: The recent of this ImapMailboxStatus.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and recent is None:  # noqa: E501
            raise ValueError("Invalid value for `recent`, must not be `None`")  # noqa: E501

        self._recent = recent

    @property
    def unseen(self):
        """Gets the unseen of this ImapMailboxStatus.  # noqa: E501

        The number of unread messages.  # noqa: E501

        :return: The unseen of this ImapMailboxStatus.  # noqa: E501
        :rtype: int
        """
        return self._unseen

    @unseen.setter
    def unseen(self, unseen):
        """Sets the unseen of this ImapMailboxStatus.

        The number of unread messages.  # noqa: E501

        :param unseen: The unseen of this ImapMailboxStatus.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and unseen is None:  # noqa: E501
            raise ValueError("Invalid value for `unseen`, must not be `None`")  # noqa: E501

        self._unseen = unseen

    @property
    def uid_next(self):
        """Gets the uid_next of this ImapMailboxStatus.  # noqa: E501

        The next UID.  # noqa: E501

        :return: The uid_next of this ImapMailboxStatus.  # noqa: E501
        :rtype: int
        """
        return self._uid_next

    @uid_next.setter
    def uid_next(self, uid_next):
        """Sets the uid_next of this ImapMailboxStatus.

        The next UID.  # noqa: E501

        :param uid_next: The uid_next of this ImapMailboxStatus.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and uid_next is None:  # noqa: E501
            raise ValueError("Invalid value for `uid_next`, must not be `None`")  # noqa: E501

        self._uid_next = uid_next

    @property
    def uid_validity(self):
        """Gets the uid_validity of this ImapMailboxStatus.  # noqa: E501

        Together with a UID, it is a unique identifier for a message. Must be greater than or equal to 1.  # noqa: E501

        :return: The uid_validity of this ImapMailboxStatus.  # noqa: E501
        :rtype: int
        """
        return self._uid_validity

    @uid_validity.setter
    def uid_validity(self, uid_validity):
        """Sets the uid_validity of this ImapMailboxStatus.

        Together with a UID, it is a unique identifier for a message. Must be greater than or equal to 1.  # noqa: E501

        :param uid_validity: The uid_validity of this ImapMailboxStatus.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and uid_validity is None:  # noqa: E501
            raise ValueError("Invalid value for `uid_validity`, must not be `None`")  # noqa: E501

        self._uid_validity = uid_validity

    @property
    def append_limit(self):
        """Gets the append_limit of this ImapMailboxStatus.  # noqa: E501

        Per-mailbox limit of message size. Set only if server supports the APPENDLIMIT extension  # noqa: E501

        :return: The append_limit of this ImapMailboxStatus.  # noqa: E501
        :rtype: int
        """
        return self._append_limit

    @append_limit.setter
    def append_limit(self, append_limit):
        """Sets the append_limit of this ImapMailboxStatus.

        Per-mailbox limit of message size. Set only if server supports the APPENDLIMIT extension  # noqa: E501

        :param append_limit: The append_limit of this ImapMailboxStatus.  # noqa: E501
        :type: int
        """

        self._append_limit = append_limit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ImapMailboxStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ImapMailboxStatus):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    MailSlurp API

    MailSlurp is an API for sending and receiving emails and SMS from dynamically allocated email addresses and phone numbers. It's designed for developers and QA teams to test applications, process inbound emails, send templated notifications, attachments, and more.  ## Resources  - [Homepage](https://www.mailslurp.com) - Get an [API KEY](https://app.mailslurp.com/sign-up/) - Generated [SDK Clients](https://docs.mailslurp.com/) - [Examples](https://github.com/mailslurp/examples) repository  # noqa: E501

    The version of the OpenAPI document: 6.5.2
    Contact: contact@mailslurp.dev
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mailslurp_client.configuration import Configuration


class LookupDkimDomainResults(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'valid': 'bool',
        'queried_name': 'str',
        'selector': 'str',
        'record': 'str',
        'algorithm': 'str',
        'key_length': 'int',
        'checked_names': 'list[str]',
        'warnings': 'list[str]',
        'errors': 'list[str]'
    }

    attribute_map = {
        'valid': 'valid',
        'queried_name': 'queriedName',
        'selector': 'selector',
        'record': 'record',
        'algorithm': 'algorithm',
        'key_length': 'keyLength',
        'checked_names': 'checkedNames',
        'warnings': 'warnings',
        'errors': 'errors'
    }

    def __init__(self, valid=None, queried_name=None, selector=None, record=None, algorithm=None, key_length=None, checked_names=None, warnings=None, errors=None, local_vars_configuration=None):  # noqa: E501
        """LookupDkimDomainResults - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._valid = None
        self._queried_name = None
        self._selector = None
        self._record = None
        self._algorithm = None
        self._key_length = None
        self._checked_names = None
        self._warnings = None
        self._errors = None
        self.discriminator = None

        self.valid = valid
        if queried_name is not None:
            self.queried_name = queried_name
        if selector is not None:
            self.selector = selector
        if record is not None:
            self.record = record
        if algorithm is not None:
            self.algorithm = algorithm
        if key_length is not None:
            self.key_length = key_length
        self.checked_names = checked_names
        self.warnings = warnings
        self.errors = errors

    @property
    def valid(self):
        """Gets the valid of this LookupDkimDomainResults.  # noqa: E501


        :return: The valid of this LookupDkimDomainResults.  # noqa: E501
        :rtype: bool
        """
        return self._valid

    @valid.setter
    def valid(self, valid):
        """Sets the valid of this LookupDkimDomainResults.


        :param valid: The valid of this LookupDkimDomainResults.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and valid is None:  # noqa: E501
            raise ValueError("Invalid value for `valid`, must not be `None`")  # noqa: E501

        self._valid = valid

    @property
    def queried_name(self):
        """Gets the queried_name of this LookupDkimDomainResults.  # noqa: E501


        :return: The queried_name of this LookupDkimDomainResults.  # noqa: E501
        :rtype: str
        """
        return self._queried_name

    @queried_name.setter
    def queried_name(self, queried_name):
        """Sets the queried_name of this LookupDkimDomainResults.


        :param queried_name: The queried_name of this LookupDkimDomainResults.  # noqa: E501
        :type: str
        """

        self._queried_name = queried_name

    @property
    def selector(self):
        """Gets the selector of this LookupDkimDomainResults.  # noqa: E501


        :return: The selector of this LookupDkimDomainResults.  # noqa: E501
        :rtype: str
        """
        return self._selector

    @selector.setter
    def selector(self, selector):
        """Sets the selector of this LookupDkimDomainResults.


        :param selector: The selector of this LookupDkimDomainResults.  # noqa: E501
        :type: str
        """

        self._selector = selector

    @property
    def record(self):
        """Gets the record of this LookupDkimDomainResults.  # noqa: E501


        :return: The record of this LookupDkimDomainResults.  # noqa: E501
        :rtype: str
        """
        return self._record

    @record.setter
    def record(self, record):
        """Sets the record of this LookupDkimDomainResults.


        :param record: The record of this LookupDkimDomainResults.  # noqa: E501
        :type: str
        """

        self._record = record

    @property
    def algorithm(self):
        """Gets the algorithm of this LookupDkimDomainResults.  # noqa: E501


        :return: The algorithm of this LookupDkimDomainResults.  # noqa: E501
        :rtype: str
        """
        return self._algorithm

    @algorithm.setter
    def algorithm(self, algorithm):
        """Sets the algorithm of this LookupDkimDomainResults.


        :param algorithm: The algorithm of this LookupDkimDomainResults.  # noqa: E501
        :type: str
        """

        self._algorithm = algorithm

    @property
    def key_length(self):
        """Gets the key_length of this LookupDkimDomainResults.  # noqa: E501


        :return: The key_length of this LookupDkimDomainResults.  # noqa: E501
        :rtype: int
        """
        return self._key_length

    @key_length.setter
    def key_length(self, key_length):
        """Sets the key_length of this LookupDkimDomainResults.


        :param key_length: The key_length of this LookupDkimDomainResults.  # noqa: E501
        :type: int
        """

        self._key_length = key_length

    @property
    def checked_names(self):
        """Gets the checked_names of this LookupDkimDomainResults.  # noqa: E501


        :return: The checked_names of this LookupDkimDomainResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._checked_names

    @checked_names.setter
    def checked_names(self, checked_names):
        """Sets the checked_names of this LookupDkimDomainResults.


        :param checked_names: The checked_names of this LookupDkimDomainResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and checked_names is None:  # noqa: E501
            raise ValueError("Invalid value for `checked_names`, must not be `None`")  # noqa: E501

        self._checked_names = checked_names

    @property
    def warnings(self):
        """Gets the warnings of this LookupDkimDomainResults.  # noqa: E501


        :return: The warnings of this LookupDkimDomainResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._warnings

    @warnings.setter
    def warnings(self, warnings):
        """Sets the warnings of this LookupDkimDomainResults.


        :param warnings: The warnings of this LookupDkimDomainResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and warnings is None:  # noqa: E501
            raise ValueError("Invalid value for `warnings`, must not be `None`")  # noqa: E501

        self._warnings = warnings

    @property
    def errors(self):
        """Gets the errors of this LookupDkimDomainResults.  # noqa: E501


        :return: The errors of this LookupDkimDomainResults.  # noqa: E501
        :rtype: list[str]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """Sets the errors of this LookupDkimDomainResults.


        :param errors: The errors of this LookupDkimDomainResults.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and errors is None:  # noqa: E501
            raise ValueError("Invalid value for `errors`, must not be `None`")  # noqa: E501

        self._errors = errors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LookupDkimDomainResults):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LookupDkimDomainResults):
            return True

        return self.to_dict() != other.to_dict()
